@@ -130,7 +130,7 @@ func loadGtkConfig() {
 			}
 		}
 	} else {
-		log.Warnf("Could'n find %s", configFile)
+		log.Warnf("Could'nt find %s", configFile)
 	}
 	log.Debugf("gtk-theme-name: %s", gtkConfig.themeName)
 	log.Debugf("gtk-icon-theme-name: %s", gtkConfig.iconThemeName)
@@ -554,7 +554,7 @@ func applyGsettingsFromFile() {
 	}
 }
 
-func saveGtkIni() {
+func saveGtkIni3() {
 	configFile := filepath.Join(configHome(), "gtk-3.0/settings.ini")
 	if !pathExists(configFile) {
 		makeDir(filepath.Join(configHome(), "gtk-3.0/"))
@@ -650,6 +650,36 @@ func saveGtkIni() {
 	saveTextFile(lines, configFile)
 }
 
+func saveGtkIni4() {
+	configFile := filepath.Join(configHome(), "gtk-4.0/settings.ini")
+	if !pathExists(configFile) {
+		makeDir(filepath.Join(configHome(), "gtk-4.0/"))
+	}
+	log.Infof(">>> Exporting %s", configFile)
+
+	lines := []string{"[Settings]"}
+
+	lines = append(lines, fmt.Sprintf("gtk-theme-name=%s", gsettings.gtkTheme))
+	lines = append(lines, fmt.Sprintf("gtk-icon-theme-name=%s", gsettings.iconTheme))
+	lines = append(lines, fmt.Sprintf("gtk-font-name=%s", gsettings.fontName))
+	lines = append(lines, fmt.Sprintf("gtk-cursor-theme-name=%s", gsettings.cursorTheme))
+	lines = append(lines, fmt.Sprintf("gtk-cursor-theme-size=%v", gsettings.cursorSize))
+
+	v := 0
+	if gsettings.colorScheme == "prefer-dark" {
+		v = 1
+	} else {
+		v = 0
+	}
+	lines = append(lines, fmt.Sprintf("gtk-application-prefer-dark-theme=%v", v))
+
+	for _, l := range lines {
+		log.Debug(l)
+	}
+
+	saveTextFile(lines, configFile)
+}
+
 func isSupported(line string) bool {
 	supported := []string{
 		"gtk-theme-name",
@@ -858,6 +888,11 @@ func linkGtk4Stuff() {
 		clearGtk4Symlinks()
 
 		// Create symlinks
+		gtk4Dir := filepath.Join(configPath, "gtk-4.0")
+		if !pathExists(gtk4Dir) {
+			makeDir(gtk4Dir)
+		}
+
 		if pathExists(filepath.Join(themePath, "gtk-4.0/gtk.css")) {
 			cmd := exec.Command("ln", "-s", filepath.Join(themePath, "gtk-4.0/gtk.css"), filepath.Join(configPath, "gtk-4.0/gtk.css"))
 			err := cmd.Run()
@@ -906,7 +941,7 @@ func linkGtk4Stuff() {
 func clearGtk4Symlinks() {
 	home := os.Getenv("HOME")
 	configPath := filepath.Join(home, ".config")
-	items := []string{"gtk-4.0/gtk.css", "gtk-4.0/gtk-dark.css", "gtk-4.0/assets", "assets"}
+	items := []string{"gtk-4.0/gtk.css", "gtk-4.0/gtk-dark.css", "gtk-4.0/assets", "assets", "gtk-4.0/settings.ini"}
 	for _, item := range items {
 		p := filepath.Join(configPath, item)
 		if pathExists(p) {
@@ -958,7 +993,10 @@ func saveIndexTheme() {
 			"Name=Default",
 			"Comment=Default Cursor Theme",
 		}
-		lines = append(lines, fmt.Sprintf("Inherits=%s", gsettings.cursorTheme))
+		// in hope to fix #90
+		if gsettings.cursorTheme != "default" {
+			lines = append(lines, fmt.Sprintf("Inherits=%s", gsettings.cursorTheme))
+		}
 		saveTextFile(lines, indexThemeFile)
 	} else {
 		log.Warn("Couldn't find icons folder")
@@ -1200,12 +1238,20 @@ func saveTextFile(text []string, path string) {
 	file.Close()
 }
 
-func listFiles(dir string) ([]os.DirEntry, error) {
+func listFiles(dir string) ([]os.FileInfo, error) {
 	files, err := os.ReadDir(dir)
-	if err == nil {
-		return files, nil
+	if err != nil {
+		return nil, err
 	}
-	return nil, err
+
+	var res []os.FileInfo
+	for _, f := range files {
+		if st, err := os.Stat(filepath.Join(dir, f.Name())); err == nil {
+			res = append(res, st)
+		}
+	}
+
+	return res, nil
 }
 
 func isIn(slice []string, val string) bool {
